@@ -14,23 +14,28 @@ class LazyType(InitialLazyType):
     back_populates: str | None = None
 
     def resolve_type(self) -> Type:
-        kls = super().resolve_type()
+        src_kls = super().resolve_type()
+        class_name = self.create_name(kls=src_kls)
+        src_kls._rel_classes = getattr(src_kls, '_rel_classes', {})
+        if class_name in src_kls._rel_classes:
+            return src_kls._rel_classes[class_name]
         kls = strawberry.type(
             type(
-                self.create_name(kls=kls),
-                (kls,), dict(kls.__dict__)
+                class_name,
+                (src_kls,), dict(src_kls.__dict__)
             ),
-            is_input=kls._type_definition.is_input,
-            is_interface=kls._type_definition.is_interface,
-            description=kls._type_definition.description,
-            directives=kls._type_definition.directives,
-            extend=kls._type_definition.extend
+            is_input=src_kls._type_definition.is_input,
+            is_interface=src_kls._type_definition.is_interface,
+            description=src_kls._type_definition.description,
+            directives=src_kls._type_definition.directives,
+            extend=src_kls._type_definition.extend
         )
         kls.__dataclass_fields__.pop(self.back_populates)
         for field_idx in range(len(kls._type_definition._fields)):
             if kls._type_definition._fields[field_idx].name == self.back_populates:
                 kls._type_definition._fields.pop(field_idx)
                 break
+        src_kls._rel_classes[class_name] = kls
         return kls
 
     def create_name(self, kls):
